sconce.datasets package
=======================

sconce.datasets.csv_image_folder module
---------------------------------------

.. automodule:: sconce.datasets.csv_image_folder
    :members:
    :undoc-members:
    :show-inheritance:

sconce.datasets.simple_dots module
----------------------------------

.. automodule:: sconce.datasets.simple_dots
    :members:
    :undoc-members:
    :show-inheritance:
